@@ -3,24 +3,9 @@ package Params::Validate::PP;
 use strict;
 use warnings;
 
+use Params::Validate::Constants;
 use Scalar::Util 1.10 ();
 
-BEGIN {
-    sub SCALAR ()    {1}
-    sub ARRAYREF ()  {2}
-    sub HASHREF ()   {4}
-    sub CODEREF ()   {8}
-    sub GLOB ()      {16}
-    sub GLOBREF ()   {32}
-    sub SCALARREF () {64}
-    sub UNKNOWN ()   {128}
-    sub UNDEF ()     {256}
-    sub OBJECT ()    {512}
-
-    sub HANDLE ()  { 16 | 32 }
-    sub BOOLEAN () { 1 | 256 }
-}
-
 our $options;
 
 # Various internals notes (for me and any future readers of this
